@@ -11,8 +11,8 @@ if !isdefined(Base, :get_extension)
     using Requires
 end
 
-using Logging, ProgressLogging, ConsoleProgressMonitor, TerminalLoggers, LoggingExtras
-using ArrayInterface, Base.Iterators, SparseArrays, LinearAlgebra, Random
+using Logging, ConsoleProgressMonitor, TerminalLoggers, LoggingExtras
+using ArrayInterface, Base.Iterators, SparseArrays, LinearAlgebra
 
 import OptimizationBase: instantiate_function, OptimizationCache, ReInitCache
 import SciMLBase: OptimizationProblem,
@@ -20,12 +20,6 @@ import SciMLBase: OptimizationProblem,
                   MaxSense, MinSense, OptimizationStats
 export ObjSense, MaxSense, MinSense
 
-include("utils.jl")
-include("state.jl")
-include("lbfgsb.jl")
-include("sophia.jl")
-include("auglag.jl")
-
 export solve
 
 end # module
